==> aliyun-python-sdk-imageenhan-1.0.0.tar.gz: aliyun-python-sdk-imageenhan-1.0.0/aliyunsdkimageenhan/request/v20190930/ExtendImageStyleRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimageenhan.endpoint import endpoint_data

class ExtendImageStyleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imageenhan', '2019-09-30', 'ExtendImageStyle')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_MajorUrl(self):
		return self.get_body_params().get('MajorUrl')

	def set_MajorUrl(self,MajorUrl):
		self.add_body_params('MajorUrl', MajorUrl)

	def get_StyleUrl(self):
		return self.get_body_params().get('StyleUrl')

	def set_StyleUrl(self,StyleUrl):
		self.add_body_params('StyleUrl', StyleUrl)

==> aliyun-python-sdk-imageenhan-1.0.7.tar.gz: aliyun-python-sdk-imageenhan-1.0.7/aliyunsdkimageenhan/request/v20190930/ExtendImageStyleRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimageenhan.endpoint import endpoint_data

class ExtendImageStyleRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imageenhan', '2019-09-30', 'ExtendImageStyle','imageenhan')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_MajorUrl(self):
		return self.get_body_params().get('MajorUrl')

	def set_MajorUrl(self,MajorUrl):
		self.add_body_params('MajorUrl', MajorUrl)

	def get_StyleUrl(self):
		return self.get_body_params().get('StyleUrl')

	def set_StyleUrl(self,StyleUrl):
		self.add_body_params('StyleUrl', StyleUrl)
